@charset "UTF-8";

/***********
 * Dialogs *
 ***********/

// .message-dialog .dialog-action-area .button {
//   //padding: 8px;
// }

messagedialog { // Message Dialog styling

    &.background { 
      background-color: gtk("@theme_bg_color");
    }
    &:backdrop { 
      background-color: gtk("@theme_unfocused_bg_color");
    }
  .titlebar {
    min-height: 32px;
    background-color: transparent;
    background-image: linear-gradient(to bottom, gtkshade("@theme_titlebar_background", 1.2117647),gtk("@theme_titlebar_background"));
    box-shadow: none;
  }
  .dialog-action-area {
    padding: 8px;
  }
  button { margin: 2px; }
}

filechooser {
  .search-bar {
    background-color: gtk("@theme_bg_color");
    border-color: gtk("@theme_bg_color");
    box-shadow: none;
    &:backdrop {
      background-color: gtk("@theme_unfocused_bg_color");
      border-color: gtk("@theme_unfocused_bg_color");
      color: gtk("@theme_unfocused_text_color");
    }
  }
  .dialog-action-box {
    border-top: 1px solid gtk("@borders");
    &:backdrop { border-top-color: gtk("@unfocused_borders"); }
  }
  #pathbarbox {
    background-color: gtk("@theme_bg_color");
    border-bottom: 1px solid gtk("@borders");
  }
}
